<?php

/*
Plugin Name: Wordpress Mobile Version Française
Plugin URI: http://www.andymoore.info/wordpress-mobile-plugin/
Description: Un plugin qui vous permet de poster et de télécharger des fichiers sur votre blog Wordpress depuis votre téléphone mobile. Il permet également aux utilisateurs de téléphones mobile de voir vos billets, archives, pages, et commentaires dans un environnement compatible avec les téléphones portables. Les visiteurs peuvent même laisser des commentaires. Ce plugin supporte les recommandations MTLD et W3 et optionnellement les revenus issus de <a href="http://www.admob.com">admob.com</a>. Une façon simple et rapide de rendre vos billets WordPress <a href="http://ready.mobi/">compatibles avec les téléphones portables</a>
Author: Andy Moore
Version: 1.2
Author URI: http://www.andymoore.info/
French version : 1.0 : March, 1st 2008 : Emmanuel Netter
Translator URI: http://www.cplusn.com
*/

/*
Copyright 2007 Andy Moore (email : andy@andymoore.info)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

// installed and tested on:
// wordpress 2.1.1
// wordpress 2.0.7
// wordpress 2.0.4
// wordpress 2.0.2

// set the version so we can check if it's upto date on admin panel
$mobile_plugin_version = '1.2';

foreach($_GET as $value => $get){
  $_GET["$value"] = htmlentities(htmlspecialchars(strip_tags($get)));
}

// if get style is css we are only showing the css then quitting
if($_GET['style']=='.css'){
  // remember not all phones can support caching style but we can try if specified
  header("Expires: " . date("D, d M Y H:i:s", time() + 60 * 60 * 24 * 30) . " GMT");
  header("Cache-Control: Public");
  header("Content-type: text/css; charset=UTF-8");
  echo mobile_style();
  exit;
}else{
  // else we're not in css mode so we set some values wordpress needs
  // make this plugin execute before any page content is sent to the browser
  // add_action('template_redirect', 'mobile_plugin_auto_detect'); 
  // make this plugin execute first to bypass cache systems etc
  add_action('template_redirect', 'mobile_plugin_auto_detect','1');
  // if installing setup the values we need and ping my install counter
  add_action('activate_wordpress-mobile.php', 'wordpress_mobile_plugin_activate');
  // if uninstalling ping my uninstall counter
  add_action('deactivate_wordpress-mobile.php', 'wordpress_mobile_plugin_deactivate');
  // create the management admin panel
  add_action('admin_menu', 'mobile_plugin_admin_menu');
}

// function to auto detect mobile phone - based on a number of methods
// this is the function that works out if it's a normal browser or a mobile browser
// more info on theory behind this: http://www.andymoore.info/php-to-detect-mobile-phones/
function mobile_plugin_auto_detect(){
  // initialise a value at zero
  $mobile_browser = '0';
  if(preg_match('/(up.browser|up.link|mmp|symbian|smartphone|midp|wap|phone|vodafone|o2|pocket|mobile|pda|psp|treo)/i',strtolower($_SERVER['HTTP_USER_AGENT']))){
    $mobile_browser++;
  }
  if(((strpos(strtolower($_SERVER['HTTP_ACCEPT']),'text/vnd.wap.wml')>0) or (strpos(strtolower($_SERVER['HTTP_ACCEPT']),'application/vnd.wap.xhtml+xml')>0)) or ((isset($_SERVER['HTTP_X_WAP_PROFILE']) or isset($_SERVER['HTTP_PROFILE'])))){
    $mobile_browser++;
  }
  $mobile_ua = strtolower(substr($_SERVER['HTTP_USER_AGENT'],0,4));
  $mobile_agents = array('acs-','alav','alca','amoi','audi','aste','avan','benq','bird','blac','blaz','brew','cell','cldc','cmd-','dang','doco','eric','hipt','inno','ipaq','java','jigs','kddi','keji','leno','lg-c','lg-d','lg-g','lge-','maui','maxo','midp','mits','mmef','mobi','mot-','moto','mwbp','nec-','newt','noki','opwv','palm','pana','pant','pdxg','phil','play','pluc','port','prox','qtek','qwap','sage','sams','sany','sch-','sec-','send','seri','sgh-','shar','sie-','siem','smal','smar','sony','sph-','symb','t-mo','teli','tim-','tosh','treo','tsm-','upg1','upsi','vk-v','voda','wap-','wapa','wapi','wapp','wapr','webc','winw','winw','xda','xda-');
  if(in_array($mobile_ua,$mobile_agents)){
    $mobile_browser++;
  }

  // now we check if mobile_browser is greater than zero or get mobi is set
  // we also check the browser isn't opera as it can render full markup'd sites
  // you can change 0 to 1 to ensure 2 tests above were passed or set it to 2 to match all three tests
  if((($mobile_browser>0) or (isset($_GET['mobi']))) and ($mobile_ua!='oper')){
    // now we know it's a mobile phone or we're to show the mobile version so we move on
    mobile_plugin_thematic_check();
  }
}

// this function works out if we need to just render content for a mobile or if we need to redirect the user to a different url
function mobile_plugin_thematic_check(){
  // where is this blog hosted?
  $home = get_settings(siteurl);
  // get the value of oneweb from the wordpress admin panel
  // you can edit this value on the admin panel
  $oneweb = get_option('wordpress_mobile_plugin_oneweb');
  // to proceed past this point we need two values mode and permalink plus an optional value oneweb
  // we only need to set oneweb if it's a mobile specific page, ie wordpress for a normal browser does not have wordpress desktop version such as the way the plugin handles listing archive pages
  // if set oneweb will override the admin panel option
  // mode is called in the query string if needed
  // are we on the index page and is no get view set
  // permalink is the url this should be viewed on
  if((is_home()) and (!isset($_GET['view']))){
    $mode ='';
    $permalink = "$home/";
  }
  // are we showing a page
  if($_GET['view']=='page'){
    $mode = '&view=page';
    $permalink = "$home/$mode";
    $oneweb = 'enabled';
  }
  // are we showing the archive index
  if($_GET['view']=='archives'){
    $mode = '&view=archives';
    $permalink = "$home/$mode";
    $oneweb = 'enabled';
  }
  // are we shoing a month, if so do we have both m (month) and y (year) values
  if(($_GET['view']=='month') and (!isset($_GET['m'])||!isset($_GET['y']))){
    $mode = "?view=archives";
    $permalink = "$home/?view=archives";
    // we have basic values m and y missing so redirect to the basic archive index
    mobile_redirect($permalink);
    exit;
  }
  // are we showing a month if so do we have the values this time (we should have)
  if(($_GET['view']=='month') and (isset($_GET['m'])&&isset($_GET['y']))){
    $mode = "?view=month&y=".$_GET['y']."&m=".$_GET['m'];
    $permalink = "$home/?view=month&y=".$_GET['y']."&m=".$_GET['m'];
  } 
  // is it an archive with no further instructions - ie archive index
  if((is_archive()) and (!isset($_GET['view']))){
    $mode = '?view=archives';
    $permalink = "$home/$mode";
    mobile_redirect($permalink);
    exit;
  }
  // are we writing a page
  if($_GET['view']=='write'){
    $mode = '&view=write';
    $permalink = "$home/$mode";
    $oneweb = 'enabled';
  }
  // are we showing a single post
  if(is_single()){
    global $post;
    $post_id = $post->ID;
    $mode = "&p=$post_id";
    $permalink = get_permalink();
  }
  // is it a page
  if(is_page()&&!$mode){
    global $post;
    $post_id = $post->ID;
    $mode = "&page=$post_id";
    $permalink = get_permalink();
  }
  // now we need to check if we're using oneweb or not
  // oneweb will preserve the permalink struct
  // it's thematic consistency if you're a geek
  if($oneweb=='enabled'){
    // we're cool to render the mobile version
    echo show_mobile_version();
  }else{
    // if mobi is set we've been instructed to show the mobile version
    if(isset($_GET['mobi'])){
      echo show_mobile_version();
    }else{
      // work out the right link to redirect to
      if(!$permalink){
        $request_uri = $_SERVER['HTTP_REQUEST_URI'];
        $link = "$home/$request_uri?mobi$mode";
      }else{
        $link = "$permalink";
        $mobi = check_mobi($permalink);
        $link = "$link$mobi";
      }
    // redirect and bow out
    mobile_redirect($link);
    exit;
    }
  }
} // ends mobile_plugin_thematic_check()

// this should only ever be run once, funnyily enough when you first install ;)
function wordpress_mobile_plugin_activate(){
  // we create a few values we need to function and propagate the admin panel with
  update_option('wordpress_mobile_plugin_admob', 'a144973d165289f', 'Code éditeur de admob.com', 'no'); // my admob code
  update_option('wordpress_mobile_plugin_admobshare', '10', 'Combien voulez-vous partager avec moi', 'no'); // my admob code
  update_option('wordpress_mobile_plugin_admoblink', 'Sites mobile sympas', 'Titre de la page des liens commerciaux', 'no'); // my admob code
  update_option('wordpress_mobile_plugin_oneweb', 'enabled', 'Support de la cohérence thématique', 'no');
  update_option('wordpress_mobile_plugin_welcome', 'Bienvenue à la version mobile de mon site!', "Commentaire principal de la page d'accueil", 'no');
  update_option('wordpress_mobile_plugin_adcomment', 'Pub:', 'Libellé pour les publicités', 'no');
  update_option('wordpress_mobile_plugin_adplacement', 'both', 'Emplacement de la publicité', 'no');
  update_option('wordpress_mobile_plugin_authorlink', 'yes', "Montrer les liens vers le site de l'auteur", 'no');
  update_option('wordpress_mobile_plugin_archivelabel', 'Archives', 'Libellé des archives', 'no');
  update_option('wordpress_mobile_plugin_pagelabel', 'Pages', 'Libellé des pages', 'no');
  update_option('wordpress_mobile_plugin_tracking', 'disabled');
  update_option('wordpress_mobile_plugin_style', 'external');
  update_option('wordpress_mobile_plugin_updatedlabel', 'Nouveau!');
  update_option('wordpress_mobile_plugin_resizewidth', '120');
  update_option('wordpress_mobile_plugin_leavecomments', 'yes');
  update_option('wordpress_mobile_plugin_showcomments', 'yes');
  // then we send a quick http request to my site so i can count how many installs there's been.
  $wpmp_install = @file_get_contents('http://www.andymoore.info/download-manager.php?id=6'); // i'm only counting installs not logging anything else
}

// hopefully you'll never want this function to be used
function wordpress_mobile_plugin_deactivate(){
  // again a simple pingback to my site to count the uninstall
  $wpmp_install = @file_get_contents('http://www.andymoore.info/download-manager.php?id=8');
}

// now we build the link in the admin menu
function mobile_plugin_admin_menu(){
  add_options_page('WordPress Mobile', 'WordPress Mobile', 3, basename(__FILE__), 'wordpress_mobile_plugin_admin');
}

// followed by building the admin panel and running the updates
function wordpress_mobile_plugin_admin(){
  // what version are we running
  global  $mobile_plugin_version;
  // find out the newest version
  $newest_version = @trim(file_get_contents('http://www.andymoore.info/wordpress-mobile-plugin-version.txt'));
  // if this is an old version update the user there's an upgrade available for download
  if("$newest_version">"$mobile_plugin_version"){
    // create the pretty box with an alert to download the new version
    $mobile_upgrade = "<div id='message' class='updated fade'><p><strong>La version $newest_version de ce plugin est maintenant disponible. La version actuelle est $mobile_plugin_version - <a href='http://www.andymoore.info/wordpress-mobile-plugin/'>T&eacute;l&eacute;chargez la derni&egrave;re version ici</a>.</strong></p></div>";
  }
  // a little page header
  echo "  <div class=\"wrap\">
  <h2>Plugin WordPress Mobile</h2>
  $mobile_upgrade";
  // we check if post admob exists
  if (isset($_POST['admob'])) {
    // it does so we can get all the other post values
    $admob = $_POST['admob'];
    $oneweb = $_POST['oneweb'];
    $welcome = $_POST['welcome'];
    if($welcome==''){
      $welcome = 'Bienvenue à la version mobile de mon site!';
    }
    $adcomment = $_POST['adcomment'];
    $adplacement = $_POST['adplacement'];
    $admoblink = $_POST['admoblink'];
    $archivelabel = $_POST['archivelabel'];
    if($archivelabel==''){
      $archivelabel = 'Archives';
    }
    $pagelabel = $_POST['pagelabel'];
    $secret = $_POST['secret'];
    $tracking = $_POST['tracking'];
    $style = $_POST['style'];
    $share = $_POST['share'];
    $authorlink = $_POST['authorlink'];
    $updatedlabel = $_POST['updatedlabel'];
    $resizewidth = $_POST['resizewidth'];
    $moblogcat = $_POST['moblogcat'];
    $leavecomments = $_POST['leavecomments'];
    $showcomments = $_POST['showcomments'];

    // now we update the options - you could add some validation here if you wished
    update_option('wordpress_mobile_plugin_admob', $admob);
    update_option('wordpress_mobile_plugin_admobshare', $share);
    update_option('wordpress_mobile_plugin_admoblink', $admoblink);
    update_option('wordpress_mobile_plugin_adcomment', $adcomment);
    update_option('wordpress_mobile_plugin_adplacement', $adplacement);
    update_option('wordpress_mobile_plugin_authorlink', $authorlink);
    update_option('wordpress_mobile_plugin_moblogcat', $moblogcat);
    update_option('wordpress_mobile_plugin_oneweb', $oneweb);
    update_option('wordpress_mobile_plugin_resizewidth', $resizewidth);
    update_option('wordpress_mobile_plugin_welcome', $welcome);
    update_option('wordpress_mobile_plugin_archivelabel', $archivelabel);
    update_option('wordpress_mobile_plugin_pagelabel', $pagelabel);
    update_option('wordpress_mobile_plugin_secret', $secret);
    update_option('wordpress_mobile_plugin_tracking', $tracking);
    update_option('wordpress_mobile_plugin_style', $style);
    update_option('wordpress_mobile_plugin_updatedlabel', $updatedlabel);
    update_option('wordpress_mobile_plugin_leavecomments', $leavecomments);
    update_option('wordpress_mobile_plugin_showcomments', $showcomments);

    // create the pretty box with updated message
    echo "<div id='message' class='updated fade'><p><strong>Options mises à jour!</strong></p></div>";
  }
  // now we get the values from wp so we can propagate the form and pre program drop down forms with selected values
  $admobkey = get_option('wordpress_mobile_plugin_admob');
  $admobshare = get_option('wordpress_mobile_plugin_admobshare');
  $admoblink = get_option('wordpress_mobile_plugin_admoblink');
  $oneweb = get_option('wordpress_mobile_plugin_oneweb');
  $welcome = get_option('wordpress_mobile_plugin_welcome');
  $adcomment = get_option('wordpress_mobile_plugin_adcomment');
  $adplacement = get_option('wordpress_mobile_plugin_adplacement');
  $archivelabel = get_option('wordpress_mobile_plugin_archivelabel');
  $pagelabel = get_option('wordpress_mobile_plugin_pagelabel');
  $secret = get_option('wordpress_mobile_plugin_secret');
  $tracking = get_option('wordpress_mobile_plugin_tracking');
  $style = get_option('wordpress_mobile_plugin_style');
  $authorlink = get_option('wordpress_mobile_plugin_authorlink');
  $updatedlabel = get_option('wordpress_mobile_plugin_updatedlabel');
  $resizewidth = get_option('wordpress_mobile_plugin_resizewidth');
  $moblogcat = get_option('wordpress_mobile_plugin_moblogcat');
  $leavecomments = get_option('wordpress_mobile_plugin_leavecomments');
  $showcomments = get_option('wordpress_mobile_plugin_showcomments');
  $homeurl = get_settings(siteurl);
  // if tracking is enabled show a link to the report page
  if($tracking=='enabled'){
    $homeurl = get_settings(siteurl);
    $homelink = ereg_replace('http://','',$homeurl);
    $mobile_counter = "<a href='http://www.waphitcounter.com/realtime.php?site=$homeurl&amp;css=$homeurl/wp-admin/wp-admin.css' target='waphitcounter'>Mobile Traffic Tracking</a>";
    $tracking_enabled = 'selected="selected"';
  }else{
    $mobile_counter = 'Analyse du trafic depuis les mobiles';
    $tracking_disabled = 'selected="selected"';
  }
  // more drop down selection checking
  if($oneweb=='enabled'){
    $selected_enabled = 'selected="selected"';
  }else{
    $selected_disabled = 'selected="selected"';
  }
  // more drop down selection checking
  if($leavecomments=='yes'){
    $comments_enabled = 'selected="selected"';
  }else{
    $comments_disabled = 'selected="selected"';
  }
  // more drop down selection checking
  if($showcomments=='yes'){
    $showcomments_enabled = 'selected="selected"';
  }else{
    $showcomments_disabled = 'selected="selected"';
  }
  // more drop down selection checking
  if($style=='internal'){
    $style_internal = 'selected="selected"';
  }else{
    $style_external = 'selected="selected"';
  }
  // more drop down selection checking
  if($authorlink=='yes'){
    $authorlink_yes = 'selected="selected"';
  }else{
    $authorlink_no = 'selected="selected"';
  }
  // where does the user want the ads to appear
  // again more drop down selection checking
  switch($adplacement){
    case 'top';
      $selected_top = 'selected="selected"';
      break;
    case 'bottom';
      $selected_bottom = 'selected="selected"';
      break;
    case 'both';
      $selected_both = 'selected="selected"';
      break;
  }
  // how much many ad exposes do you want me to get?
  // again more drop down selection checking
  switch($admobshare){
    case '10';
      $share_10 = 'selected="selected"'; // thanks!
      break;
    case '25';
      $share_25 = 'selected="selected"';
      break;
    case '50';
      $share_50 = 'selected="selected"';
      break;
    case '100';
      $share_100 = 'selected="selected"'; 
      break;
  }



  global $wpdb;
  $cat_drop = '<select name="moblogcat" id="moblogcat">';
  $categories = @$wpdb->get_results("SELECT * FROM $wpdb->categories ORDER BY cat_name");
  foreach ($categories as $category){
    if ($category->cat_ID == $moblogcat){
      $selected = " selected='selected'";
    }else{
      $selected = '';
    }
    $cat_drop .= "\n\t<option value='$category->cat_ID' $selected>".ucwords(strtolower($category->cat_name))."&nbsp;&nbsp;</option>";
  }
  $cat_drop .= '</select>';


  // show the admin panel form and links etc
  echo "  <p><b>Votre site Wordpress est maintenant mobile!</b> </p>
  <fieldset class='options'>
	<legend>Configuration g&eacute;n&eacute;rale du plugin</legend>
  <form name='wordpress_mobile_update' id='wordpress_mobile_update' method='post' action='?page=wordpress-mobile.php&amp;action=wordpress_mobile_update' ENCTYPE='multipart/form-data'>
  <table cellpadding='3' cellspacing='3'>
	<tr>
	<td width='250'>Message d'accueil:</td>
	<td width='250'><input type='text' name='welcome' value='$welcome' size='45' /></td>
	</tr>
	<tr>
	<td width='250'>Libell&eacute; des archives:</td>
	<td width='250'><input type='text' name='archivelabel' value='$archivelabel' size='15' /></td>
	</tr>
	<tr>
	<td width='250'>Libell&eacute; des pages:</td>
	<td width='250'><input type='text' name='pagelabel' value='$pagelabel' size='15' /></td>
	</tr>
  <tr>
	<td width='250'>Afficher les commentaires:</td>
	<td width='250'><select name='showcomments'><option value='yes' $showcomments_enabled>Oui&nbsp;&nbsp;<option value='no' $showcomments_disabled>Non</select></td>
	</tr>
  <tr>
	<td width='250'>Laisser des commentaires:</td>
	<td width='250'><select name='leavecomments'><option value='yes' $comments_enabled>Oui&nbsp;&nbsp;<option value='no' $comments_disabled>Non</select></td>
	</tr>
  <tr>
	<td width='250'>Texte &agrave; afficher si le blog &agrave; &eacute;t&eacute; mis &agrave; jour:</td>
	<td width='250'><input type='text' name='updatedlabel' value='$updatedlabel' size='15' /></td>
	</tr>
  <tr>
	<td width='250'>CSS interne ou externe:</td>
	<td width='250'><select name='style'><option value='external' $style_external>Externe&nbsp;&nbsp;<option value='internal' $style_internal>Interne</select></td>
	</tr>
  <tr>
	<td width='250'><a href='http://www.w3.org/TR/mobile-bp/#OneWeb' target='oneweb'>One Web</a> / Pr&eacute;server les permaliens</td>
	<td width='250'><select name='oneweb'><option value='enabled' $selected_enabled>Oui<option value='disabled' $selected_disabled>Non&nbsp;&nbsp;</select></td>
	<td width='500'></td>
	</tr>
  <tr>
	<td width='250'>$mobile_counter:</td>
	<td width='250'><select name='tracking'><option value='enabled' $tracking_enabled>Oui<option value='disabled' $tracking_disabled>Non&nbsp;&nbsp;</select></td>
	</tr>
	</table>
	<br />
  <legend>Ecrire des billets depuis votre mobile</legend>
  <br />
  <br />
  <table cellpadding='3' cellspacing='3'>
	<tr>
	<td width='250'>Code secret pour autoriser l'&eacute;criture depuis votre mobile:</td>
	<td width='250'><input type='text' name='secret' value='$secret' size='15' /></td>
	</tr>
	<tr>
	<td width='250'>Cat&eacute;gorie par d&eacute;faut:</td>
	<td width='250'>$cat_drop</td>
	</tr>
  <tr>
	<td width='250'>Redimensionner les images jpg t&eacute;l&eacute;charg&eacute;es plus grandes que :</td>
	<td width='250'><input type='text' name='resizewidth' value='$resizewidth' size='5' /> (pixels)</td>
	</tr>
	</table>
	<br />
  <legend>AdMob Publicit&eacute;s Internet pour Mobiles</legend>
  <br />
  <br />
  <table cellpadding='3' cellspacing='3'>
	<tr>
	<td width='250'><a href='http://www.admob.com/' target='admob'>AdMob</a> ID d'auteur mobile:</td>
	<td width='250'><input type='text' name='admob' value='$admobkey' size='15' /></td>
	</tr>
	<tr>
	<td width='250'>Titre des publicit&eacute;s:</td>
	<td width='250'><input type='text' name='adcomment' value='$adcomment' size='10' /></td>
	</tr>
  <tr>
	<td width='250'>Position des publicit&eacute;s:</td>
	<td width='250'><select name='adplacement'><option value='top' $selected_top>Haut<option value='bottom' $selected_bottom>Bas<option value='both' $selected_both>Les deux</select></td>
	</tr>
  <tr>
	<td width='250'>Libell&eacute; des publicit&eacute;s:</td>
	<td width='250'><input type='text' name='admoblink' value='$admoblink' size='15' /></td>
	</tr>
	</table>
	<br />
  <legend>Partagez votre succ&egrave;s</legend>
  <br />
  <br />
  <table cellpadding='3' cellspacing='3'>
  <tr>
	<td width='250'>Partagez vos revenus publicitaires avec l'auteur:</td>
	<td width='250'><select name='share'><option value='10' $share_10>1 sur 10<option value='25' $share_25>1 sur 25<option value='50' $share_50>1 sur 50<option value='100' $share_100>1 sur 100</select></td>
	<td width='500'></td>
	</tr>
  <tr>
	<td width='250'>Afficher les liens vers l'auteur du plugin :</td>
	<td width='250'><select name='authorlink'><option value='yes' $authorlink_yes>Oui&nbsp;&nbsp;<option value='no' $authorlink_no>Non</select></td>
	<td width='500'></td>
	</tr>
	</table>
	<input type='submit' name='update_wordpress_mobile' value='Mettre &agrave; jour!' />
  </form>
  </fieldset>
	</div>
	<div class=\"wrap\">
  <h3>Outils de d&eacute;veloppement pour Mobiles, bonnes pratiques et ressources</h3>
  <p>
  <a href='http://pc.mtld.mobi'target='mtld'><img src='http://www.andymoore.info/wp-content/uploads/2007/02/dotmobi.jpg' width='86' height='38' border='0' alt='Dot Mobi'/></a>
  &nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;
  <a href='http://www.admob.com/'target='admob'><img src='http://www.admob.com/img/admob_logo_banner.gif' width='209' height='34' border='0' alt='Admob' /></a>
  </p>
  <ul>
  <li><a href='http://validator.w3.org/mobile?uri=$homeurl'target='validator'>validator.w3.org/mobile</a> - V&eacute;rifiez votre code
  <li><a href='http://ready.mobi/results2.jsp?uri=$homeurl' target='ready'>ready.mobi</a> - V&eacute;rifiez si vous êtes prêts pour les mobiles.
  <li><a href='http://emulator.mtld.mobi/emulator.php?emulator=&amp;webaddress=$homelink&amp;emulator=nokiaN70' target='emulator'>emulator.mtld.mobi</a> - N'oubliez pas de tester sur plusieurs mobiles r&eacute;els.
  <li><a href='http://jigsaw.w3.org/css-validator/validator?uri=$homeurl?style=.css'target='stylevali'>jigsaw.w3.org/css-validator</a> - V&eacute;rifiez votre style
  <li><a href='http://pc.dev.mobi/files/dotMobi%20Mobile%20Web%20Developers%20Guide.pdf' target='devguide'>dotMobi Mobile Web Developers Guide</a> - Lecture recommand&eacute;e
  <li><a href='http://www.w3.org/TR/mobileOK-basic10-tests/' target='mobileOK'>W3C mobileOK Basic Tests 1.0</a> - le document de travail du W3
  </ul>
  <p>
  Plugin d&eacute;velopp&eacute; par <a href='http://www.andymoore.info' target='andy'>Andy Moore</a> d&eacute;veloppeur internet mobile. Traduction par <a href='http://www.cplusn.com' target='cplusn'>Emmanuel Netter</a>
  </p>
  </div>";
// ends the admin panel function
}

// this is just a standard 301 redirect to the url passed
function mobile_redirect($link){
  header('HTTP/1.1 301 Moved Permanently');
  header('Status: 301 Moved Permanently');
  header("Location: $link");
}

// this helps show friendly file sizes when items have been uploaded from a phone
// from www.php.net/filesize
function size_hum_read($size){
  $i=0;
  $iec = array("b", "kb", "mb");
  while (($size/1024)>1) {
   $size = $size/1024;
   $size = number_format($size,2);
   $i++;
  }
  return substr($size,0,strpos($size,'.')+4).' '.$iec[$i];
}

// if we need to add a mobi get value to the url it comes in handy to know if it's a directory or query stung page we're showing so we can select either ?mobi or &mobi
// used a lot more when one web is disabled as it needs to work out where to reidrect the user to
function check_mobi($link){
  $oneweb = get_option('wordpress_mobile_plugin_oneweb');
  if($oneweb=='disabled'){
    $lastchar = $link[strlen($link)-1];
    if($lastchar=='/'){
      $mobi = '?mobi';
    }else{
      $mobi = '&mobi';
    }
  }
  return $mobi;
}

// function to make the call to admob and pick up the ads we show
function admob($admobkey){
 $mob_ua = urlencode(getenv("HTTP_USER_AGENT"));
 $mob_ip = urlencode($_SERVER['REMOTE_ADDR']);
 $mob_mode=='false';
 if ($mob_mode=='true'){
  $mob_m = "&m";
 }
 // how much are you sharing? - it's appreciated if you do. it encourages me to release this stuff
 $admobshare = get_option('wordpress_mobile_plugin_admobshare');
 // randomise and set against admobshare to work out my id or publisher's id
 $campaign = (rand() % $admobshare == 0) ? 'a144973d165289f' : $admobkey;
 // clicks for code, sounds fair to me, if you're anal or ungrateful uncomment the line below
 // $campaign = $admobkey; 
 $mob_url = "http://ads.admob.com/ad_source.php?s=$campaign&u=$mob_ua&i=$mob_ip$mob_m";
 @$mob_ad_serve = file_get_contents($mob_url);
 if ($mob_ad_serve!=""){
  $mob_link = explode("><",$mob_ad_serve);
  $mob_ad_text = ereg_replace('--> ','',ereg_replace('&','&amp;',$mob_link[0]));
  $mob_ad_link = $mob_link[1];
  if($mob_ad_link!=""){
    $ads = '';
    $ads = "<a href='$mob_ad_link' accesskey='0' rel='nofollow'>$mob_ad_text</a>";
  }
 }
 // adding &adshare to the url will replace ads with the details of the author share and who that ad esposure would be credited to
 if(isset($_GET['adshare'])){
  $campaign = ($campaign == 'a144973d165289f') ? 'Auteur du plugin' : 'Auteur du blog';
  $ads = "Info pub: Auteur partage: 1 sur $admobshare - Somme totale: $campaign ";
 }
 return $ads;
}

// when we call post content we run a nl2br on it which creates markup we then need to clean
// sounds silly but it's easier to clean it this way than any other
// return clean will also trim a whole load of whitespace, newlines, tabs, returns etc so that the markup we show the device is as optimal as can be
function clean_return($return){
  $return = str_replace(array("\n", "\r", "\t", "<!--adsense--><br /><br />", "<br /><br /><!--donate-->", "<!--adsense#Sense--><br /><br />", "<!--adsense#FirefoxLarge--><br /><br />"," align=\"center\""), '', $return);
  $return = ereg_replace (' +', ' ', trim($return));
  $return = ereg_replace('<atitle>','<title>',$return);
  $return = ereg_replace('& ','&amp; ',$return);
  $return = ereg_replace('<br /><br /></p>','</p>',$return);
  $return = ereg_replace('<br /></p>','</p>',$return);
  $return = ereg_replace('</li><br />','</li>',$return);
  $return = ereg_replace('<ul><br />','<ul>',$return);
  $return = ereg_replace('</ul><br />','</ul>',$return);
  $return = ereg_replace('</p><br />','</p>',$return);
  $return = ereg_replace('</blockquote><br />','</blockquote>',$return);
  $return = ereg_replace('<blockquote><br />','<blockquote>',$return);
  $return = ereg_replace('<br /><br /><blockquote>','<blockquote>',$return);
  $return = ereg_replace('<br /></strong><br /><br />','</strong><br /><br />',$return);
  $return = ereg_replace('<br /></a></strong><br /><br />','</a></strong><br /><br />',$return);
  $return = ereg_replace('</blockquote><br />','</blockquote>',$return);
  return "$return";
}

// hackup up version from alex king
function next_post_m($format='%', $next='next post: ', $title='yes', $in_same_cat='no', $limitnext=1, $excluded_categories='') {
	global $tableposts, $p, $posts, $id, $post, $blogfilename, $wpdb;
	global $time_difference, $single;	
	global $querystring_start, $querystring_equal, $querystring_separator;
	if(($p) || ($posts==1) || 1 == $single) {
		$current_post_date = $post->post_date;
		$current_category = $post->post_category;
		$sqlcat = '';
		if ($in_same_cat != 'no') {
			$sqlcat = " AND post_category='$current_category' ";
		}
		$sql_exclude_cats = '';
		if (!empty($excluded_categories)) {
			$blah = explode('and', $excluded_categories);
			foreach($blah as $category) {
				$category = intval($category);
				$sql_exclude_cats .= " AND post_category != $category";
			}
		}
		$now = date('Y-m-d H:i:s');
		$limitnext--;
		$nextpost = @$wpdb->get_row("SELECT ID,post_title FROM $tableposts WHERE post_date > '$current_post_date' AND post_date < '$now' AND post_status = 'publish' $sqlcat $sql_exclude_cats ORDER BY post_date ASC LIMIT $limitnext,1");
    if ($nextpost) {
  		$link = get_permalink($nextpost->ID);
  		$linkmobi = check_mobi($link);
			$string = "[2] <a href='$link$linkmobi' accesskey='2'>$next";
			if ($title=='yes') {
				$string .= wptexturize(stripslashes($nextpost->post_title));
			}
			$string .= '</a>';
			$format = str_replace('%', $string, $format);
			return $format;
		}
	}
}

// again an alex king function
function previous_post_m($format='%', $previous='previous post: ', $title='yes', $in_same_cat='no', $limitprev=1, $excluded_categories='') {
	global $tableposts, $id, $post, $blogfilename, $wpdb;
	global $p, $posts, $posts_per_page, $s, $single;
	global $querystring_start, $querystring_equal, $querystring_separator;
	if (($p) || ($posts_per_page == 1) || 1 == $single) {
		$current_post_date = $post->post_date;
		$current_category = $post->post_category;
		$sqlcat = '';
		if ($in_same_cat != 'no') {
			$sqlcat = " AND post_category = '$current_category' ";
		}
		$sql_exclude_cats = '';
		if (!empty($excluded_categories)) {
			$blah = explode('and', $excluded_categories);
			foreach($blah as $category) {
				$category = intval($category);
				$sql_exclude_cats .= " AND post_category != $category";
			}
		}
		$limitprev--;
		$lastpost = @$wpdb->get_row("SELECT ID, post_title FROM $tableposts WHERE post_date < '$current_post_date' AND post_status = 'publish' $sqlcat $sql_exclude_cats ORDER BY post_date DESC LIMIT $limitprev, 1");
		if ($lastpost) {
  		$link = get_permalink($lastpost->ID);
  		$linkmobi = check_mobi($link);
			$string = "[1] <a href='$link$linkmobi' accesskey='1'>$previous";
			if ($title == 'yes'){
        $string .= wptexturize(stripslashes($lastpost->post_title));
      }
			$string .= '</a>';
			$format = str_replace('%', $string, $format);
			return $format;
		}
	}
}

// this is how we show the pages to mobiles
// first off we build up some variables about the environment so we know what we're meant to show
// we create the meta and title tags with these values them use the display value as the toggle on a switch to create the page content
// seems a bit discombobulated but this method works
function show_mobile_version(){
  // get some basic values
  $home = get_settings(siteurl);
  $archivelabel = get_option('wordpress_mobile_plugin_archivelabel');
  $pagelabel = get_option('wordpress_mobile_plugin_pagelabel');
  $admobkey = get_option('wordpress_mobile_plugin_admob');
  $oneweb = get_option('wordpress_mobile_plugin_oneweb');
  $userip = $_SERVER['REMOTE_ADDR'];
  $ua = $_SERVER['HTTP_USER_AGENT'];
  // check the user is not the w3 emulator or ready.mobi test so we can hide from them markup they might not like
  // sounds like going against best practices but the best practices say sometimes you need to do it
  if($userip=='84.51.241.159'||$userip=='84.51.242.25'||$userip=='83.138.189.132'||eregi('w3',strtolower($ua))){
    // tool is yes, this can come in handy later on
    $tool = 'yes';
  }
 // Month names for localized version
  $month_lc = Array("", "Janvier", "Février", "Mars", "Avril", "Mai", "Juin", "Juillet", "Août", "Septembre", "Octobre", "Novembre", "Décembre");
 
  // get the post data
  global $post;
  $post_id = $post->ID;
  // same as before but we do it to get different variables
  // this is one of my peaves with this script, i built it up from an old version that used to double cook the values
  // till i have the time to sit and prepare a proper framework to rebuild from this will have to do
  // display is used to pass what to show to the switch
  // blogtitle, blogheader, blog title and description are used in the page header and meta tags
  // is page and no view
  if((is_home()) and (!isset($_GET['view']))){
    $display = 'index';
    $description = get_bloginfo ('description');
    $metatitle = get_bloginfo('name') ." | $description";
    $blogtitle = get_bloginfo('name');
    $blogheader = "$description";
  }
  // is archive and view
  if((is_archive()) or (isset($_GET['view']))){
    $view = $_GET['view'];
    if($view=='archives'){
      $description = $archivelabel;
      $blogheader = get_bloginfo('name');
    }
    if($view=='pages'){
      $description = $pagelabel;
      $blogheader = get_bloginfo('name');
    }
    if($view=='write'){
      $description = 'Nouveau billet';
      $blogheader = get_bloginfo('name');
    }
    if($view=='month'){
      $year = $_GET['y'];
      $month = $_GET['m'];
      $fullmonth = $month_lc[intval($month)]; // Support for localized months names
      $description = "$fullmonth $year";
      $blogheader = $archivelabel.' | '.get_bloginfo('name');
    }
    $metatitle = "$description | $blogheader";
    $blogtitle = $description;
    $display = $view;
  }
  // is just a post
  if(is_single()){
    $display = "post";
    $title = get_the_title();
    $blogheader = get_bloginfo('name');
    if(isset($_GET['comments'])){
      $show_comments = 'Comments on ';
    }
    $metatitle = "$show_comments$title | $blogheader";
    $blogtitle = $title;
  }
  // is a page but no mode is set
  if(is_page()&&!$mode){
    $display = "page";
    $title = get_the_title();
    $blogheader = get_bloginfo('name');
    $metatitle = "$title | ".get_bloginfo('name');
    $blogtitle = $title;
  }
  // global wordpress stuff
  global $wpdb;
	$time_difference = get_settings('gmt_offset');
	$now = gmdate("Y-m-d H:i:s",time());
  // bring on the switch to create the page output
  switch($display){  
    // showing frontpage
    case 'index';
      // this is the header on the index - only show on index
      $mobile_intro = get_option('wordpress_mobile_plugin_welcome');
      $return = "<p class='content'>$mobile_intro</p>
      <p class='list'>";
      $request = "SELECT ID, post_title FROM $wpdb->posts WHERE post_status = 'publish' AND post_date < '$now' ORDER BY post_date DESC LIMIT 5";
    	$posts = $wpdb->get_results($request);
    	if($posts){
        foreach ($posts as $post){
          $post_title = stripslashes($post->post_title);
          $permalink = get_permalink($post->ID);
          if($accesskey<5&&$accesskey!='none'){
            $accesskey++;
            $access = "accesskey='$accesskey' ";
            $accessvisual = "[$accesskey] ";
          }else{
            $accesskey = 'none';
            unset($accessvisual);
            unset($access);
          }
          $mobi = ereg_replace('&','&amp;',check_mobi($permalink));
          $return .= "$accessvisual<a href='$permalink$mobi' $access>$post_title</a><br />";
        }
      }
      $return .= "</p>";
    break;
    // the archives index
    case 'archives';
      $return = "<p class='content'>Vous consultez le sommaire des $archivelabel.</p>
      <p class='list'>";
      $request = "SELECT DISTINCT YEAR(post_date) as year, MONTH(post_date) as month FROM $wpdb->posts WHERE post_date < '$now' AND post_status = 'publish' ORDER BY post_date DESC";
    	$posts = $wpdb->get_results($request);
    	if($posts){
        foreach ($posts as $post){
          $year = $post->year;
          $month = $post->month;
          $fullmonth = $month_lc[intval($month)];  // Support for localized months names
          if($accesskey<5&&$accesskey!='none'){
            $accesskey++;
            $access = "accesskey='$accesskey' ";
            $accessvisual = "[$accesskey] ";
          }else{
            $accesskey = 'none';
            unset($accessvisual);
            unset($access);
          }
          $mobi = ereg_replace('&','&amp;',check_mobi($permalink));
          $return .= "$accessvisual<a href='?view=month&amp;y=$year&amp;m=$month&amp;mobi' $access>$fullmonth $year</a><br />";
        }
      }
      $return .= "</p>";
    break;
    // a particular month
    case 'month';
      $return = "<p class='content'>Vous consultez les $archivelabel pour $fullmonth $year.</p>
      <p class='list'>";
      $request = "SELECT ID, post_title, post_date FROM $wpdb->posts WHERE MONTH(post_date) = '".$_REQUEST["m"]."' AND YEAR(post_date) = '".$_REQUEST["y"]."' AND post_status = 'publish' ORDER BY post_date DESC";
    	$posts = $wpdb->get_results($request);
    	if($posts){
        foreach ($posts as $post){
          $title = $post->post_title;
          $permalink = get_permalink($post->ID);
          if($accesskey<5&&$accesskey!='none'){
            $accesskey++;
            $access = "accesskey='$accesskey' ";
            $accessvisual = "[$accesskey] ";
          }else{
            $accesskey = 'none';
            unset($accessvisual);
            unset($access);
          }
          $mobi = ereg_replace('&','&amp;',check_mobi($permalink));
          $return .= "$accessvisual<a href='$permalink$mobi' $access>$title</a><br />";
        }
      }
      $return .= "</p>";
    break;
    // an individual post
    case 'post';
      start_wp();

      $navi = '<p class="nextprev">';
      $prev = previous_post_m('%','Pr&eacute;c&eacute;dent: ');
      if($prev!=''){
       $navi .= "$prev<br />";
      }
      $next = next_post_m('%','Suivant: ');
      if($next!=''){
       $navi .= "$next";
      }
      $navi .= "</p>";

      $link = get_permalink($post_id);
      $title = get_the_title();
      $numberofcomments = $wpdb->get_var("SELECT COUNT(comment_ID) FROM $wpdb->comments WHERE comment_post_ID = $post_id AND comment_approved !='spam'");
      $leavecomments = get_option('wordpress_mobile_plugin_leavecomments');
      if($numberofcomments>0){
        if($numberofcomments>1){
          $areoris = 'are';
          $singularorplurar = 's';
        }else{
          $areoris = 'is';
          $singularorplurar = '';
        }
      }else if($numberofcomments=='0'){
        $numberofcomments = 'Aucun';
        $areoris = 'are';
        $singularorplurar = '';
      }
      $lastchar = $link[strlen($link)-1];
      if($lastchar=='/'){
        $mobi = '?mobi';
      }else{
        $mobi = '&amp;mobi';
      }
      if($_GET['comments']!="$post_id"){
        $title = get_the_title();
        $page_content = get_the_content();
        $return .= '<div class="content">';
        $return .= str_replace('target="_blank"','',nl2br($page_content));
        // display liks to comments if enabled and there are comments
        $status = $wpdb->get_var("SELECT comment_status FROM $wpdb->posts WHERE ID = '$post_id'");
        $showcomments = get_option('wordpress_mobile_plugin_showcomments');
        if($showcomments=='yes'&&$status=='open'){
          $return .= "<h3>Commentaires</h3><div class='comments'><a href='$link$mobi&amp;comments=$post_id&amp;page=1'>$numberofcomments commentaire$singularorplurar pour $title</a>.</div>";
        }
        $return .= "</div>";
        $return .= "$navi";
      }else{
        $perpage = 5;
        $page = mysql_real_escape_string($_GET['page']);
        if($page==''){
          $page = '1';
        }
        if($page=='1'){
          $start = '0';
        }else{
          $start = $page * $perpage - $perpage;
        }
        $pages = ceil($numberofcomments / $perpage);
        // if the page is higher than 1 we need to generate the previous link
        if($page > 1){
          $prev = ($page - 1);
          $navigation .= "<a href='$link$mobi&amp;comments=$post_id&amp;page=$prev'>Derni&egrave;re page</a> ";
        }
        if($page>1 && $page<$pages){
          $navigation .= '| ';
        }
        // if the page is lower than the total number of pages we need to generate the next link
        if($page < $pages){
          $next = ($page + 1);
          $navigation .= "<a href='$link$mobi&amp;comments=$post_id&amp;page=$next'>Page suivante</a>";
        }
        $return .= '<div class="content">';
        $return .= "<h2>$numberofcomments commentaire$singularorplurar pour $title</h2><p>";
        
        if($pages!='0' && $pages>1){
          $return .= "Page $page de $pages";
          $return .=" | $navigation<br />";
        }
        $return .="[1] <a href='$link' accesskey='1'>Retour à $title</a></p>";
        $comments = $wpdb->get_results("SELECT * FROM $wpdb->comments WHERE comment_post_ID = '$post_id' and comment_approved !='spam' order by comment_date asc limit $start, $perpage");
        foreach ($comments as $comment){

// print_r($comment);
// exit;
          $countem++;
          if($counter!='1'){
            $return .= '<br />';
          }
          $comment_author = $comment->comment_author;
          $comment_content = ereg_replace('&','&amp;',$comment->comment_content);
          $comment_date = $comment->comment_date_gmt;
          $comment_author = $comment->comment_author;
          $comment_author_url = $comment->comment_author_url;
          if($comment_author_url!=''){
            $comment_author = "<a href='$comment_author_url'>$comment_author</a>";
          }
          $return .= "<strong>Le $comment_date, $comment_author a dit</strong><br />'<cite>$comment_content</cite>'<br />";
        }
        $return .= "</div><p><strong>$navigation</strong></p>";
        // showing comments
        if($leavecomments=='yes'){
          $return .= '<p><strong>Ajoutez votre commentaire:</strong><a id="submitcomment">&nbsp;</a></p>';
          $return .= "<form action='$home/wp-comments-post.php' method='post' id='commentform'>
          <p>
          <label for='author'>[2] Requis - Nom:</label>
          <br />
          <input type='text' name='author' id='author' value='' size='22' tabindex='1'  accesskey='2'/>
          <br />
          <label for='email'>[3] Requis - Email, sera cach&eacute;:</label>
          <br />
          <input type='text' name='email' id='email' value='' size='22' tabindex='2'  accesskey='3'/>
          <br />
          <label for='url'>Site web / adresse dotMobi:</label>
          <br />
          <input type='text' name='url' id='url' value='' size='22' tabindex='3' />
          <br />
          <label for='url'>[4] Votre commentaire:</label>
          <br />
          <textarea name='comment' id='comment' cols='20' rows='5' tabindex='4' accesskey='4'></textarea>
          <br />
          <label for='url'>[5] Envoyer votre commentaire!</label>
          <br />
          <input name='submit' type='submit' id='submit' tabindex='5' accesskey='5' value=' Envoyer votre commentaire ' />
          <input type='hidden' name='comment_post_ID' value='$post_id' />
          </p>
          </form>
          <p>[1] <a href='$link' accesskey='1'>Retour à $title</a></p>";
        }
      }

    break;
    // an individual page
    case 'page';
      start_wp();
      $title = get_the_title().' | '.$pagelabel;
      $page_content = get_the_content();
      $return .= '<div class="content">';
      $return .= str_replace('target="_blank"','',nl2br($page_content));
      $return .= "</div>";
    break;
    // pages index
    case 'pages';
      start_wp();
      $title = get_the_title().' | '.$pagelabel;
      $return = "<p class='content'>Vous consultez le sommaire de $pagelabel.</p>
      <p class='list'>";
      $pages = get_pages();
      foreach($pages as $page) {
        $page_title = $page->post_title;
        $page_name =  $page->post_name;
        $page_permalink =  get_permalink($page->ID);
        if($accesskey<5&&$accesskey!='none'){
          $accesskey++;
          $access = "accesskey='$accesskey' ";
          $accessvisual = "[$accesskey] ";
        }else{
          $accesskey = 'none';
          unset($accessvisual);
          unset($access);
        }
        $mobi = ereg_replace('&','&amp;',check_mobi($permalink));
        $return .= "$accessvisual<a href='$page_permalink' $access>$page_title</a><br />";
      }
      $return .= "</p>";
    break;
    // writing a post
    // this originally came from http://niksblick.de/153
    // one big change is the addition of loads of file types to check against attached posts contains file download info (size & type) for mobile devices
    // this will check if gd is installed and if it is and a file is a jpeg and larger than specified size it will resize and make the thumb
    case 'write';
      // supported file types for upload, well extensions really as that's what we check them against
      $types = array('avi','3gp','amr','awb','wav','mid','mid','thm','mmf','sis','cab','mp3','gif','jpeg','jpg','jar','aac','mp4');
      sort($types);
      foreach ($types as $type){
        $supported .= "$type ";
      }
      // if posting get some values and proceed to validate
      // if everything is okay we need a continue value to equal yes
      if(isset($_POST['submit'])){
        $code = $_POST['code'];
        $title = $_POST['title'];
        $postcontent = $_POST['postcontent'];
        $publish_cat = $_POST['publish_cat'];
        // validation
        if($code==''||$title==''||$postcontent==''){
          $page_info .= '<strong>Billet pas envoy&eacute;.</strong> Vous devez fournir un code, un titre et un billet pour continuer. ';
          $continue = 'no';
        }
        // validation
        $postsecret = get_option('wordpress_mobile_plugin_secret');
        if($code!="$postsecret"&&$continue!='no'){
          $page_info .= '<strong>Billet pas envoy&eacute;.</strong> Le code secret saisi est incorrect. Pour mettre à jour votre code secret allez à wp-admin > options > wordpress mobile';
          $continue = 'no';
        }
        // check if there's a file being uploaded
        if(!strcmp(basename($_FILES['upload']['name']), '')) {
        	$hasupload = 'no';
        }else{
          $hasupload = 'yes';
          $upload_type = explode('.',$_FILES['upload']['name']);
          $upload_type = strtolower(trim($upload_type['1'])); // gets the extension
          // check that type is okay and proceed if in the array
          if(in_array($upload_type,$types)){
            // get the value of the directory where we will store the file server side
            $dir_file_path = $_SERVER["DOCUMENT_ROOT"] .'/'.attribute_escape(str_replace(ABSPATH, '', get_settings('upload_path'))) .'/';
            // setup the file name server side
            $file_path = $dir_file_path . basename( $_FILES['upload']['name']);
            // it's online address
            $file_urlpath = $home .'/'.attribute_escape(str_replace(ABSPATH, '', get_settings('upload_path'))) .'/';
            // get resize width from options
            $resize_width = get_option('wordpress_mobile_plugin_resizewidth');
            // if we have a positive value we are setting resize to true as in the original plugin
            if($resize_width>0){
              $resize = true;
            }
            // get public urls for the files and sort out any spaces in the file name
            $full_file_url = $file_urlpath . basename( $_FILES['upload']['name']);
            $full_file_url = ereg_replace(' ','%20', $full_file_url);
            $thumb_file_url = $file_urlpath.'thumb-' . basename( $_FILES['upload']['name']);
            $thumb_file_url = ereg_replace(' ','%20', $thumb_file_url);
            // check the file has been uploaded and moved okay
            if(move_uploaded_file($_FILES['upload']['tmp_name'], $file_path)) {
              // chmod the file
              chmod($file_path, 0644);
              // check if gd library is installed, resize is true and the iimage type is jpg or jpeg
              if((extension_loaded('gd')&&$resize) and ($upload_type=='jpeg'||$upload_type=='jpg')){
                  // get file values
                  $upload_size = size_hum_read($_FILES['upload']['size']);
                  $img = imagecreatefromjpeg($file_path);
                  $imgx = imagesx($img);
                  $imgy = imagesy($img);
                  // check if it's wider than the resize limit
                  if($imgx > $resize_width) {
                    // resize copy for thumbnail
                    $resize_height = $imgy * $resize_width / $imgx;
                    $thumb = ImageCreateTrueColor($resize_width, $resize_height);
                    ImageCopyResampled($thumb, $img, 0, 0, 0, 0, $resize_width, $resize_height, $imgx, $imgy);
                    $thumb_file_path = $dir_file_path.'thumb-' . basename( $_FILES['upload']['name']);
                    imagejpeg($thumb, $thumb_file_path, 65);
                    // get height and width values we can use in markup
                    $img_height = round($resize_height);
                    $img_width = round($resize_width);
                    // set these values in tags
                    $img_dimensions = 'height="'.$img_height.'" width="'.$img_width.'" ';
                    // build the url of the file we show / link to
                    $show_file_url = $file_urlpath."thumb-" . basename( $_FILES['upload']['name']);
                  } else {
                    // get height and width values we can use in markup
                    $img_height = round($imgy);
                    $img_width = round($imgx);
                    // set these values in tags
                    $img_dimensions = 'height="'.$img_height.'" width="'.$img_width.'" ';
                    // build the url of the file we show / link to
                    $show_file_url = $file_urlpath. basename( $_FILES['upload']['name']);
                  } 
              // there's either no support for gd, resize is null or it's not a jpg or jpeg
              }else{
                // another file type so just get the file size
                $upload_size = size_hum_read($_FILES['upload']['size']);
              }
              // work out the type so we can echo what kind of file it is
              $upload_format = explode('/',$_FILES['upload']['type']);
              $upload_format = strtolower(trim($upload_format['0']));
              // if it's an image we build the img tag
              if($upload_format=='image'){
                $link_tag = '<a href="'.$full_file_url.'">';
                $image_tag = '<img src="'.$show_file_url.'" '.$img_dimensions.' alt="'.$title.'" /></a><br />';
              }
              // build the file upload value we use in the post content
              $file_upload = "<br /><br /><strong>Info fichier:</strong><br />Type: $upload_format $upload_type<br />Size: $upload_size<br /><a href=\"$full_file_url\">$title</a><br />";
            // ends upload and move okay
            }else{
              // something went pear shaped
              $page_info .= '<strong>Billet pas envoy&eacute;.</strong> Impossible de t&eacute;l&eacute;charger ce fichier. V&eacute;rifiez votre configuration, et en particulier les droits du r&eacute;pertoire upload de Wordpress.';
              $continue = 'no';
            }
          }else{
            // dodgy file type spotted
            $postcontent .= '<strong>Billet pas envoy&eacute;.</strong> Le type de votre fichier est "'.$upload_type.'" Format de fichier non autoris&eacute;.';
            $continue = 'no';
          }
        }
      // if continue is not no we are able to insert the post 
      if($continue!='no'){
        // form the post title
        $post_title = $title;
        // set the post content
        $post_content = "<strong>Envoy&eacute; d'un t&eacute;l&eacute;phone mobile:</strong><br />$link_tag$image_tag$postcontent$file_upload";
        // set the author as admin
        $post_author = 1;
        // set up values to insert into database
        $post_category = array(get_option('wordpress_mobile_plugin_moblogcat'));
        $post_status = 'publish';
        $post_date = current_time('mysql');
        $post_date_gmt = current_time('mysql', 1);
        $post_data = compact('post_content','post_title','post_date','post_date_gmt','post_author','post_category', 'post_status');
        // insert
        $post_ID = wp_insert_post($post_data);
        if($post_ID > 0) {
          // if okay show link
          $permalink = get_permalink($post_ID);
          $page_info .= "<strong>Billet publi&eacute;!</strong><br /><a href='$permalink'>$post_title</a>";
        } else {
          // if goofed say so
          $page_info .= "<strong>Publication impossible</strong><br />D&eacute;sol&eacute;, une erreur est intervenue lors de l'insertion dans la base de donn&eacute;es.";
        }
      }
      // ends there being post values
      }else{
        // not posted so show simple intro
        $page_info .= "Ecrivez &amp; t&eacute;l&eacute;chargez de n'import o&ugrave;! Les types de fichiers support&eacute;s pour le t&eacute;l&eacute;chargement sont: $supported";
      }
      // if it's a tool it's not going to like the file tag so we hide it from the w3 etc...
      if($tool!='yes'){
        $filefield = "<br /><label accesskey='4' for='upload'>[4] T&eacute;l&eacute;chargement de fichier - optionnel:</label><br /><input type='file' name='upload' id='upload'/>";
      }
      // get a friendly name for the category
      $moblogcat = ucwords(strtolower(get_cat_name(get_option('wordpress_mobile_plugin_moblogcat'))));
      // build up the form with the page_info to alert the user to what is what.
      $return = "<p class='content'>$page_info<br />Les billets seront publi&eacute;s dans $moblogcat</p>
      <form enctype='multipart/form-data' action='$home/?mobi&amp;view=write' method='post'>
      <p>
      <label accesskey='1' for='code'>[1] Code secret:</label>
      <br />
      <input type='text' name='code' id='code' class='write' value='$code'/>
      <br />
      <label accesskey='2' for='title'>[2] Titre du billet:</label>
      <br />
      <input type='text' name='title' id='title' class='write' value='$title'/>
      <br />
      <label accesskey='3' for='postcontent'>[3] Contenu du billet:</label>
      <br />
      <textarea name='postcontent' id='postcontent' class='write' cols='20' rows='3'>$postcontent</textarea>
      $filefield
      <br />
      <input type='hidden' name='view' id='view' value='write' />
      <input type='hidden' name='mobi' id='mobi' value='' />
      <label accesskey='5' for='submit'>[5] Publiez votre billet!</label>
      <br />
      <input type='submit' name='submit' id='submit' accesskey='5' value=' Cliquez pour publier ' />	
      </p>
      </form>";
    break;
  }
  // if admobkey is set and it's not a tool we do the admob stuff
  // we hide the ads from the emulator and w3 as they create an error as they are not providing supported headers
  if($admobkey!=''&&$tool!='yes'){
    // where do you want them
    $adplacement = get_option('wordpress_mobile_plugin_adplacement');
    // any comment to go next to them
    $adcomment = trim(get_option('wordpress_mobile_plugin_adcomment'));
    // do you want a link to a links page, if so what do we call it
    $admoblink = trim(get_option('wordpress_mobile_plugin_admoblink'));
    // we need to know if you're showing my links
    // if you show my links the css class for ads is admob
    // if you're not showing my links we set the calls to foot to enable the contrast on the page
    $authorlink = trim(get_option('wordpress_mobile_plugin_authorlink'));
    if($authorlink=='no'){
      $adclass = 'foot';
    }else{
      $adclass = 'admob';
    }
    // is there really an adcomment?
    if($adcomment!=''){
      $adcomment .= ' ';
    }
    // work out where we want the ads
    // the optional links page will only ever show on the bottom or when both is selected
    switch($adplacement){
      case 'top';
        $admob = '<div class="admob">'.$adcomment.'[0] '.admob($admobkey).'</div>';
        break;
      case 'bottom';
        if($admoblink!=''){
          $linkspage = " <br /><a href='http://ads.admob.com/link_list.php?s=$admobkey'>$admoblink</a>";
        }
        $admobbottom = '<div class="'.$adclass.'">'.$adcomment.' '.ereg_replace("accesskey='0' ",'',admob($admobkey)).$linkspage.'</div>';
        break;
      case 'both';
        $admob = '<div class="admob">'.$adcomment.'[0] '.admob($admobkey).'</div>';
        if($admoblink!=''){
          $linkspage = " <br /><a href='http://ads.admob.com/link_list.php?s=$admobkey'>$admoblink</a>";
        }
        $admobbottom = '<div class="'.$adclass.'">'.$adcomment.' '.ereg_replace("accesskey='0' ",'',admob($admobkey)).$linkspage.'</div>';
        break;
    }
  }
  // a few variables to customise
  $home = get_settings(siteurl);
  $bloginfo = get_bloginfo('name');
  if(isset($_GET['mobi'])){
    $navmobi = '?mobi';
  }
  // we only show the create post page is the secret has a value
  $secret = get_option('wordpress_mobile_plugin_secret');
  if($secret!=''){
    $write_page_link = "<br />[9] <a href='$home?mobi&amp;view=write' accesskey='9'>Nouveau billet</a>";
  }
  // if there is a value for pagelabel and there are actually some pages we build the pages_link value
  if(($pagelabel!='') and (pages_count()>0)){
    $pages_link = "<br />[8] <a href='$home/?view=pages&amp;mobi' accesskey='8'>$pagelabel</a>";
  }
  // build up the navigation variable
  $navigation = "[6] <a href='$home/$navmobi' accesskey='6'>$bloginfo</a><br />[7] <a href='$home/?view=archives&amp;mobi' accesskey='7'>$archivelabel</a>$pages_link$write_page_link";
  // are you showing author links or not?
  // again we don't show these to validators and emulators or the w3
  $authorlink = get_option('wordpress_mobile_plugin_authorlink');
  if($tool!='yes'&&$authorlink!='no'){
    /*
    // i was looking for an even rotation on the link text we use to help me target to terms on each link
    $web2txt_anchor = '<a href="http://www.web2txt.co.uk/wap/">';
    $web2txt_anchor .= (rand() % 2 == 0) ? 'Mp3 Tracks' : 'Ringtones';
    $web2txt_anchor .= '</a>';
    // then i thought that individual search terms would be better.....
    */
    $web2txt_values       = array();
    $web2txt_values['0']  = array('CTU Phone', '36880');
    $web2txt_values['1']  = array('24 Phone', '36880');
    $web2txt_values['2']  = array('Sopranos', '37255');
    $web2txt_values['3']  = array('Mosquito', '342393');
    $web2txt_values['4']  = array('Dr Who', '36374');
    $web2txt_values['5']  = array('Smack That', '342776');
    $web2txt_values['6']  = array('Spongebob', '340515');
    $web2txt_values['7']  = array('Exorcist', '36958');
    $web2txt_values['8']  = array('Ring of Fire', '38980');
    $web2txt_values['9']  = array('Muppet Show', '340051');
    $web2txt_values['10'] = array('Mr Big Stuff', '35722');
    $web2txt_values['11'] = array('Sweet Escape', '343667');
    $web2txt_values['12'] = array('Grace Kelly', '343540');
    $web2txt_values['13'] = array('Monty Python', '35333');
    $web2txt_values['14'] = array('Chasing Cars', '342098');
    $web2txt_count        = count($web2txt_values)-1;
    $web2txt_rand         = rand('0',$web2txt_count);
    $web2txt_anchor       = $web2txt_values[$web2txt_rand]['0'];
    $web2txt_id           = $web2txt_values[$web2txt_rand]['1'];
    $web2txt_anchor       = '<a href="http://www.web2txt.co.uk/wap/v2/order.php?product='.$web2txt_id.'">'.$web2txt_anchor.' Ringtone</a>';
    $my_anchor = (rand() % 2 == 0) ? 'WordPress Mobile' : 'D&eacute;veloppeur web mobile';
    // build up the backlink value
    $backlink = "<div class='foot'>$web2txt_anchor | <a href='http://www.andymoore.info/wordpress-mobile-plugin/'>$my_anchor</a></div>";
  }
  // how do we want to handle the stylesheet
  $style = get_option('wordpress_mobile_plugin_style');
  if($style=='external'){
    // if external we build up the link href value
    $mobile_style = "<link href='$home/?mobi&amp;style=.css' rel='stylesheet' type='text/css' />";
  }else{
    // else we include it inline in a style tag
    $mobile_style = "<style type='text/css'>".mobile_style()."</style>";
  }
  // see if a page or post has been created or updated today so we can show the site is current
  $updated = updated_today();

  // set up header so the handset can cache them if supported
  header("Expires: " . date("D, d M Y H:i:s", time() + 60 * 60) . " GMT");
  header("Cache-Control: Public");
  header("Pragma: Public");
  // valid content type
  header('Content-Type: application/xhtml+xml; charset=UTF-8');
  $close = '>'; // just to keep syntax highlighting in editor.
  // just so i can see what version you're using if i check out your site
  global $mobile_plugin_version;
  // this is the page template 
  // indentation (pretty printing) will be removed before we echo to the browser 
  $return = <<<ENDOFDOC
<?xml version="1.0" encoding="UTF-8"?$close
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML Basic 1.0//EN" "http://www.w3.org/TR/xhtml-basic/xhtml-basic10.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
  <head>
    <title>$metatitle</title>
    $mobile_style
    <meta name="generator" content="Plugin WordPress Mobil French Version. Version: $mobile_plugin_version - andymoore.info. Translation: cplusn.com" />
  </head>
  <body>
    <h1 class="title">$blogtitle</h1>
    <h2 class="title">$blogheader$updated</h2>
    $admob
    $return
    <div class="nav">$navigation</div>
    $backlink
    $admobbottom
  </body>
</html>
ENDOFDOC;

 // clean it up - remove junk characters
 echo clean_return($return);

  // find out if we're to track this click
  $tracking = get_option('wordpress_mobile_plugin_tracking');
  if($tracking=='enabled'){
    // waphitcounter.com needs a few values to track your clicks and help you return a clickstream analysis
    $site = $home;
    $action = $metatitle;
    $url = urlencode($_SERVER['SERVER_NAME'].$_SERVER['REQUEST_URI']);
    $ua = urlencode(getenv('HTTP_USER_AGENT'));
    $ip = urlencode(getenv('REMOTE_ADDR'));
    $referer = urlencode(getenv('HTTP_REFERER'));
    // where we post to
    $host = 'waphitcounter.com';
    $path = '/log.php';
    // what we are to psot
    $parameters = "site=$site&ua=$ua&ip=$ip&action=$action&referer=$referer&url=$url";
    // do it!
    $fp = fsockopen($host, 80);
    fputs($fp, "POST $path HTTP/1.1\r\n");
    fputs($fp, "Host: $host\r\n");
    fputs($fp, "Content-type: application/x-www-form-urlencoded\r\n");
    fputs($fp, "Content-length: " . strlen($parameters) . "\r\n");
    fputs($fp, "User-Agent: $ua\r\n");
    fputs($fp, "Connection: close\r\n\r\n");
    fputs($fp, $parameters);
    while (!feof($fp)) {
     $data .= fgets($fp,128);
    }
    fclose($fp);
  }
  exit;
}

// this simply returns the style sheet - will either be called inline or as an external file call by adding &style=.css to the URL
function mobile_style(){
  $style_title_background = "#BBBBBB";
  $style_border = "#666666";
  $style_content_background = "#EEEEEE";
  $style_nav_background = "#CCCCCC";
  $style_foot_background = "#DDDDDD";
  $style_foot_color = "#666666";
  $mobile_style = "body{background:#FFFFFF; font-family:Verdana, Arial, Helvetica, sans-serif; font-size:0.80em; line-height:2.00em; color:#000000;}
  a{text-decoration: none; color:#FF0000}
  a:hover{text-decoration: none; color:#000000}
  .title{background: $style_title_background; color:#ffffff; margin:0em; font-size:1.1em; font-weight: bold; padding:0.13em 0em 0.13em 1.00em;}
  .admob{border-bottom: $style_border solid 0.13em; background: $style_nav_background; margin:0EM; padding:0.13em 0em 0.13em 1.00em;}
  .list{margin:0em; padding:0.13em 0em 0.13em 1.00em;}
  .top{background: $style_foot_background; margin:0em; padding:0.13em 0em 0.13em 1.00em;}
  .nav{border-top: $style_border solid 0.13em; background: $style_nav_background; margin:0em; padding:0.13em 0em 0.13em 1.00em;}
  .content{border-bottom: $style_border solid 0.13em; background: $style_content_background; margin:0em; padding:0.13em 0em 0.13em 1.00em;}
  .foot{border-top: $style_border solid 0.13em; border-bottom: $style_border solid 0.13em; background: $style_foot_background; color: $style_foot_color; margin: 0em; padding:0.13em 0em 0.13em 1.00em;}
  .nextprev{background: $style_foot_background; color:$style_foot_color; margin: 0em; padding:0.13em 0em 0.13em 1.00em;}
  input.write{-wap-input-format: \"*M\"}
  textarea.write{-wap-input-format: \"*M\"}";

  return clean_return($mobile_style);
}

// function / sql originally from http://insomniacsyndicate.net/speak/?page_id=19 made 1.5 friendly
function updated_today(){
	global $wpdb;
    $updatedlabel = get_option('wordpress_mobile_plugin_updatedlabel');
    if($updatedlabel!=''){
      $today = date("Y-m-d");
    	$updated = $wpdb->get_var("select post_date, id FROM $wpdb->posts WHERE $wpdb->posts.post_date LIKE '".$today."%'");
    	if ($updated>0){; 
    	 return "<br />".$updatedlabel;
    	}
    }
}

// function originally from http://perishablepress.com/press/2006/08/28/blogstats-pcc-plugin/
function pages_count() {
	global $wpdb;
	global $numpages;
	$numpages = $wpdb->get_var("SELECT COUNT(*) FROM $wpdb->posts WHERE post_status = 'static'");
	if ($numpages>0){; 
	 return $numpages;
	}
}

// wow you mean you actually read my code?
// www.andymoore.info/
// www.andymoore.info/wordpress-mobile-plugin/

// thanks for using my software!

?>
